==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/DetailsList/DetailsColumn/DetailsColumn.base.js <==
import '../../node_modules/core-js/modules/es.array.concat.js';
import '../../node_modules/core-js/modules/es.date.to-string.js';
import '../../node_modules/core-js/modules/es.object.to-string.js';
import '../../node_modules/core-js/modules/es.reflect.construct.js';
import '../../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent.js';
import '../../node_modules/core-js/modules/es.function.name.js';
import '../../node_modules/core-js/modules/es.number.constructor.js';
import { DEFAULT_CELL_STYLE_PROPS } from '../DetailsRow/DetailsRow.styles.js';
import { FontIcon } from '../../Icon/FontIcon.js';
import { Icon } from '../../Icon/index.js';
import { ColumnActionsMode } from '../DetailsList.types.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var MOUSEDOWN_PRIMARY_BUTTON = 0;
var getClassNames = classNamesFunction();
var TRANSITION_DURATION_DRAG = 200;
var TRANSITION_DURATION_DROP = 1500;
var CLASSNAME_ADD_INTERVAL = 20;

var DetailsColumnBase = function (_BaseComponent) {
  _inherits(DetailsColumnBase, _BaseComponent);

  var _super = _createSuper(DetailsColumnBase);

  function DetailsColumnBase() {
    var _this;

    _classCallCheck(this, DetailsColumnBase);

    _this = _super.apply(this, arguments);
    _this.ColumnActionsMode = ColumnActionsMode;
    return _this;
  }

  _createClass(DetailsColumnBase, [{
    key: "mounted",
    value: function mounted() {
      var _this2 = this;

      if (this.dragDropHelper && this.isDraggable) {
        this._addDragDropHandling();
      }

      var classNames = this.classNames;

      if (this.isDropped) {
        if (this.$refs.root) {
          this.$refs.root.classList.add(classNames.borderAfterDropping);

          this._async.setTimeout(function () {
            if (_this2.$refs.root) {
              _this2.$refs.root.classList.add(classNames.noBorderAfterDropping);
            }
          }, CLASSNAME_ADD_INTERVAL);
        }

        this._async.setTimeout(function () {
          if (_this2.$refs.root) {
            _this2.$refs.root.classList.remove(classNames.borderAfterDropping);

            _this2.$refs.root.classList.remove(classNames.noBorderAfterDropping);
          }
        }, TRANSITION_DURATION_DROP + CLASSNAME_ADD_INTERVAL);
      }
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      if (this._dragDropSubscription) {
        this._dragDropSubscription.dispose();
      }

      this._async.dispose();

      this.events.dispose();
    }
  }, {
    key: "updated",
    value: function updated() {
      if (!this._dragDropSubscription && this.dragDropHelper && this.isDraggable) {
        this._addDragDropHandling();
      }

      if (this._dragDropSubscription && !this.isDraggable) {
        this._dragDropSubscription.dispose();

        this.events.off(this.$refs.root, 'mousedown');
      }
    }
  }, {
    key: "_onColumnClick",
    value: function _onColumnClick(ev) {
      var onColumnClick = this.onColumnClick,
          column = this.column;

      if (column.columnActionsMode === ColumnActionsMode.disabled) {
        return;
      }

      if (column.onColumnClick) {
        column.onColumnClick(ev, column);
      }

      if (onColumnClick) {
        onColumnClick(ev, column);
      }
    }
  }, {
    key: "_getColumnDragDropOptions",
    value: function _getColumnDragDropOptions() {
      var _this3 = this;

      var columnIndex = this.columnIndex;
      var options = {
        selectionIndex: columnIndex,
        context: {
          data: columnIndex,
          index: columnIndex
        },
        canDrag: function canDrag() {
          return _this3.isDraggable;
        },
        canDrop: function canDrop() {
          return false;
        },
        onDragStart: this._onDragStart,
        updateDropState: function updateDropState() {
          return undefined;
        },
        onDrop: function onDrop() {
          return undefined;
        },
        onDragEnd: this._onDragEnd
      };
      return options;
    }
  }, {
    key: "_onDragStart",
    value: function _onDragStart(item, itemIndex, selectedItems, event) {
      var _this4 = this;

      var classNames = this.classNames;

      if (itemIndex) {
        this._updateHeaderDragInfo(itemIndex);

        this.$refs.root.classList.add(classNames.borderWhileDragging);

        this._async.setTimeout(function () {
          if (_this4.$refs.root) {
            _this4.$refs.root.classList.add(classNames.noBorderWhileDragging);
          }
        }, CLASSNAME_ADD_INTERVAL);
      }
    }
  }, {
    key: "_onDragEnd",
    value: function _onDragEnd(item, event) {
      var classNames = this.classNames;

      if (event) {
        this._updateHeaderDragInfo(-1, event);
      }

      this.$refs.root.classList.remove(classNames.borderWhileDragging);
      this.$refs.root.classList.remove(classNames.noBorderWhileDragging);
    }
  }, {
    key: "_updateHeaderDragInfo",
    value: function _updateHeaderDragInfo(itemIndex, event) {
      if (this.updateDragInfo) {
        this.updateDragInfo({
          itemIndex: itemIndex
        }, event);
      }
    }
  }, {
    key: "_onRootMouseDown",
    value: function _onRootMouseDown(ev) {
      var isDraggable = this.isDraggable;

      if (isDraggable && ev.button === MOUSEDOWN_PRIMARY_BUTTON) {
        ev.stopPropagation();
      }
    }
  }, {
    key: "_onColumnContextMenu",
    value: function _onColumnContextMenu(ev) {
      var onColumnContextMenu = this.onColumnContextMenu,
          column = this.column;

      if (column.onColumnContextMenu) {
        column.onColumnContextMenu(column, ev);
        ev.preventDefault();
      }

      if (onColumnContextMenu) {
        onColumnContextMenu(column, ev);
        ev.preventDefault();
      }
    }
  }, {
    key: "_addDragDropHandling",
    value: function _addDragDropHandling() {
      this._dragDropSubscription = this.dragDropHelper.subscribe(this.$refs.root, this.events, this._getColumnDragDropOptions());
      this.events.on(this.$refs.root, 'mousedown', this._onRootMouseDown);
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          column = this.column,
          columnIndex = this.columnIndex,
          columnWidth = this.columnWidth,
          IconComponent = this.IconComponent,
          isDraggable = this.isDraggable,
          parentId = this.parentId;
      return h("div", {
        "ref": "root",
        "key": column.key,
        "class": classNames.root,
        "attrs": {
          "aria-sort": column.isSorted ? column.isSortedDescending ? 'descending' : 'ascending' : 'none',
          "aria-colindex": columnIndex,
          "role": "columnheader"
        },
        "style": {
          width: columnWidth
        }
      }, [isDraggable && h(IconComponent, {
        "attrs": {
          "icon-name": "GripperBarVertical"
        },
        "class": classNames.gripperBarVerticalStyle
      }), h("span", {
        "class": classNames.cellTooltip
      }, [h("span", {
        "attrs": {
          "id": "".concat(parentId, "-").concat(column.key),
          "aria-label": column.isIconOnly ? column.name : undefined,
          "aria-labelledby": column.isIconOnly ? undefined : "".concat(parentId, "-").concat(column.key, "-name")
        },
        "class": classNames.cellTitle,
        "on": {
          "contextmenu": this._onColumnContextMenu,
          "click": this._onColumnClick
        }
      }, [h("span", {
        "attrs": {
          "id": "".concat(parentId, "-").concat(column.key, "-name")
        },
        "class": classNames.cellName
      }, [(column.iconName || column.iconClassName) && h(IconComponent, {
        "class": classNames.iconClassName,
        "attrs": {
          "icon-name": column.iconName
        }
      }), column.isIconOnly ? h("span", {
        "class": classNames.accessibleLabel
      }, [column.name]) : column.name]), column.isFiltered && h(IconComponent, {
        "class": classNames.nearIcon,
        "attrs": {
          "icon-name": "Filter"
        }
      }), column.isSorted && h(IconComponent, {
        "class": classNames.sortIcon,
        "attrs": {
          "icon-name": column.isSortedDescending ? 'SortDown' : 'SortUp'
        }
      }), column.isGrouped && h(IconComponent, {
        "class": classNames.nearIcon,
        "attrs": {
          "icon-name": "GroupedDescending"
        }
      }), column.columnActionsMode === ColumnActionsMode.hasDropdown && !column.isIconOnly && h(IconComponent, {
        "attrs": {
          "icon-name": "ChevronDown"
        }
      })])])]);
    }
  }, {
    key: "IconComponent",
    get: function get() {
      return this.useFastIcons ? FontIcon : Icon;
    }
  }, {
    key: "classNames",
    get: function get() {
      var column = this.column,
          columnIndex = this.columnIndex,
          styles = this.styles,
          theme = this.theme,
          _this$cellStyleProps = this.cellStyleProps,
          cellStyleProps = _this$cellStyleProps === void 0 ? DEFAULT_CELL_STYLE_PROPS : _this$cellStyleProps;
      return getClassNames(styles, {
        theme: theme,
        headerClassName: column.headerClassName,
        iconClassName: column.iconClassName,
        isActionable: column.columnActionsMode !== ColumnActionsMode.disabled,
        isEmpty: !column.name,
        isIconVisible: column.isSorted || column.isGrouped || column.isFiltered,
        isPadded: column.isPadded,
        isIconOnly: column.isIconOnly,
        cellStyleProps: cellStyleProps,
        transitionDurationDrag: TRANSITION_DURATION_DRAG,
        transitionDurationDrop: TRANSITION_DURATION_DROP
      });
    }
  }, {
    key: "columnWidth",
    get: function get() {
      var column = this.column,
          cellStyleProps = this.cellStyleProps;
      return column.calculatedWidth + cellStyleProps.cellLeftPadding + cellStyleProps.cellRightPadding + (column.isPadded ? cellStyleProps.cellExtraRightPadding : 0) + 'px';
    }
  }]);

  return DetailsColumnBase;
}(BaseComponent);

__decorate([Prop({
  type: Object,
  required: true
}), __metadata("design:type", Object)], DetailsColumnBase.prototype, "column", void 0);

__decorate([Prop({
  type: Number,
  required: true
}), __metadata("design:type", Number)], DetailsColumnBase.prototype, "columnIndex", void 0);

__decorate([Prop({
  type: Number,
  "default": null
}), __metadata("design:type", Number)], DetailsColumnBase.prototype, "parentId", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], DetailsColumnBase.prototype, "onColumnClick", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], DetailsColumnBase.prototype, "onColumnContextMenu", void 0);

__decorate([Prop({
  type: Object,
  "default": null
}), __metadata("design:type", Object)], DetailsColumnBase.prototype, "dragDropHelper", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], DetailsColumnBase.prototype, "isDraggable", void 0);

__decorate([Prop({
  type: Function,
  "default": null
}), __metadata("design:type", Function)], DetailsColumnBase.prototype, "updateDragInfo", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], DetailsColumnBase.prototype, "isDropped", void 0);

__decorate([Prop({
  type: Object,
  "default": function _default() {
    return DEFAULT_CELL_STYLE_PROPS;
  }
}), __metadata("design:type", Object)], DetailsColumnBase.prototype, "cellStyleProps", void 0);

__decorate([Prop({
  type: Boolean,
  "default": true
}), __metadata("design:type", Boolean)], DetailsColumnBase.prototype, "useFastIcons", void 0);

DetailsColumnBase = __decorate([Component({
  components: {}
})], DetailsColumnBase);

export { DetailsColumnBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/DetailsList/DetailsColumn/DetailsColumn.base.js <==
import 'core-js/modules/es.array.concat';
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import BaseComponent from '../../BaseComponent.js';
import 'core-js/modules/es.function.name';
import 'core-js/modules/es.number.constructor';
import { DEFAULT_CELL_STYLE_PROPS } from '../DetailsRow/DetailsRow.styles.js';
import { FontIcon } from '../../Icon/FontIcon.js';
import { Icon } from '../../Icon/index.js';
import { ColumnActionsMode } from '../DetailsList.types.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var MOUSEDOWN_PRIMARY_BUTTON = 0;
var getClassNames = classNamesFunction();
var TRANSITION_DURATION_DRAG = 200;
var TRANSITION_DURATION_DROP = 1500;
var CLASSNAME_ADD_INTERVAL = 20;

var DetailsColumnBase = function (_BaseComponent) {
  _inherits(DetailsColumnBase, _BaseComponent);

  var _super = _createSuper(DetailsColumnBase);

  function DetailsColumnBase() {
    var _this;

    _classCallCheck(this, DetailsColumnBase);

    _this = _super.apply(this, arguments);
    _this.ColumnActionsMode = ColumnActionsMode;
    return _this;
  }

  _createClass(DetailsColumnBase, [{
    key: "mounted",
    value: function mounted() {
      var _this2 = this;

      if (this.dragDropHelper && this.isDraggable) {
        this._addDragDropHandling();
      }

      var classNames = this.classNames;

      if (this.isDropped) {
        if (this.$refs.root) {
          this.$refs.root.classList.add(classNames.borderAfterDropping);

          this._async.setTimeout(function () {
            if (_this2.$refs.root) {
              _this2.$refs.root.classList.add(classNames.noBorderAfterDropping);
            }
          }, CLASSNAME_ADD_INTERVAL);
        }

        this._async.setTimeout(function () {
          if (_this2.$refs.root) {
            _this2.$refs.root.classList.remove(classNames.borderAfterDropping);

            _this2.$refs.root.classList.remove(classNames.noBorderAfterDropping);
          }
        }, TRANSITION_DURATION_DROP + CLASSNAME_ADD_INTERVAL);
      }
    }
  }, {
    key: "beforeDestroy",
    value: function beforeDestroy() {
      if (this._dragDropSubscription) {
        this._dragDropSubscription.dispose();
      }

      this._async.dispose();

      this.events.dispose();
    }
  }, {
    key: "updated",
    value: function updated() {
      if (!this._dragDropSubscription && this.dragDropHelper && this.isDraggable) {
        this._addDragDropHandling();
      }

      if (this._dragDropSubscription && !this.isDraggable) {
        this._dragDropSubscription.dispose();

        this.events.off(this.$refs.root, 'mousedown');
      }
    }
  }, {
    key: "_onColumnClick",
    value: function _onColumnClick(ev) {
      var onColumnClick = this.onColumnClick,
          column = this.column;

      if (column.columnActionsMode === ColumnActionsMode.disabled) {
        return;
      }

      if (column.onColumnClick) {
        column.onColumnClick(ev, column);
      }

      if (onColumnClick) {
        onColumnClick(ev, column);
      }
    }
  }, {
    key: "_getColumnDragDropOptions",
    value: function _getColumnDragDropOptions() {
      var _this3 = this;

      var columnIndex = this.columnIndex;
      var options = {
        selectionIndex: columnIndex,
        context: {
          data: columnIndex,
          index: columnIndex
        },
        canDrag: function canDrag() {
          return _this3.isDraggable;
        },
        canDrop: function canDrop() {
          return false;
        },
        onDragStart: this._onDragStart,
        updateDropState: function updateDropState() {
          return undefined;
        },
        onDrop: function onDrop() {
          return undefined;
        },
        onDragEnd: this._onDragEnd
      };
      return options;
    }
  }, {
    key: "_onDragStart",
    value: function _onDragStart(item, itemIndex, selectedItems, event) {
      var _this4 = this;

      var classNames = this.classNames;

      if (itemIndex) {
        this._updateHeaderDragInfo(itemIndex);

        this.$refs.root.classList.add(classNames.borderWhileDragging);

        this._async.setTimeout(function () {
          if (_this4.$refs.root) {
            _this4.$refs.root.classList.add(classNames.noBorderWhileDragging);
          }
        }, CLASSNAME_ADD_INTERVAL);
      }
    }
  }, {
    key: "_onDragEnd",
    value: function _onDragEnd(item, event) {
      var classNames = this.classNames;

      if (event) {
        this._updateHeaderDragInfo(-1, event);
      }

      this.$refs.root.classList.remove(classNames.borderWhileDragging);
      this.$refs.root.classList.remove(classNames.noBorderWhileDragging);
    }
  }, {
    key: "_updateHeaderDragInfo",
    value: function _updateHeaderDragInfo(itemIndex, event) {
      if (this.updateDragInfo) {
        this.updateDragInfo({
          itemIndex: itemIndex
        }, event);
      }
    }
  }, {
    key: "_onRootMouseDown",
    value: function _onRootMouseDown(ev) {
      var isDraggable = this.isDraggable;

      if (isDraggable && ev.button === MOUSEDOWN_PRIMARY_BUTTON) {
        ev.stopPropagation();
      }
    }
  }, {
    key: "_onColumnContextMenu",
    value: function _onColumnContextMenu(ev) {
      var onColumnContextMenu = this.onColumnContextMenu,
          column = this.column;

      if (column.onColumnContextMenu) {
        column.onColumnContextMenu(column, ev);
        ev.preventDefault();
      }

      if (onColumnContextMenu) {
        onColumnContextMenu(column, ev);
        ev.preventDefault();
      }
    }
  }, {
    key: "_addDragDropHandling",
    value: function _addDragDropHandling() {
      this._dragDropSubscription = this.dragDropHelper.subscribe(this.$refs.root, this.events, this._getColumnDragDropOptions());
      this.events.on(this.$refs.root, 'mousedown', this._onRootMouseDown);
    }
  }, {
    key: "render",
    value: function render() {
      var h = arguments[0];
      var classNames = this.classNames,
          column = this.column,
          columnIndex = this.columnIndex,
          columnWidth = this.columnWidth,
          IconComponent = this.IconComponent,
          isDraggable = this.isDraggable,
          parentId = this.parentId;
      return h("div", {
        "ref": "root",
        "key": column.key,
        "class": classNames.root,
        "attrs": {
          "aria-sort": column.isSorted ? column.isSortedDescending ? 'descending' : 'ascending' : 'none',
          "aria-colindex": columnIndex,
          "role": "columnheader"
        },
        "style": {
          width: columnWidth
        }
      }, [isDraggable && h(IconComponent, {
        "attrs": {
          "icon-name": "GripperBarVertical"
        },
        "class": classNames.gripperBarVerticalStyle
      }), h("span", {
        "class": classNames.cellTooltip
      }, [h("span", {
        "attrs": {
          "id": "".concat(parentId, "-").concat(column.key),
          "aria-label": column.isIconOnly ? column.name : undefined,
          "aria-labelledby": column.isIconOnly ? undefined : "".concat(parentId, "-").concat(column.key, "-name")
        },
        "class": classNames.cellTitle,
        "on": {
          "contextmenu": this._onColumnContextMenu,
          "click": this._onColumnClick
        }
      }, [h("span", {
        "attrs": {
          "id": "".concat(parentId, "-").concat(column.key, "-name")
        },
        "class": classNames.cellName
      }, [(column.iconName || column.iconClassName) && h(IconComponent, {
        "class": classNames.iconClassName,
        "attrs": {
          "icon-name": column.iconName
        }
      }), column.isIconOnly ? h("span", {
        "class": classNames.accessibleLabel
      }, [column.name]) : column.name]), column.isFiltered && h(IconComponent, {
        "class": classNames.nearIcon,
        "attrs": {
          "icon-name": "Filter"
        }
      }), column.isSorted && h(IconComponent, {
        "class": classNames.sortIcon,
        "attrs": {
          "icon-name": column.isSortedDescending ? 'SortDown' : 'SortUp'
        }
      }), column.isGrouped && h(IconComponent, {
        "class": classNames.nearIcon,
        "attrs": {
          "icon-name": "GroupedDescending"
        }
      }), column.columnActionsMode === ColumnActionsMode.hasDropdown && !column.isIconOnly && h(IconComponent, {
        "attrs": {
          "icon-name": "ChevronDown"
        }
      })])])]);
    }
  }, {
    key: "IconComponent",
    get: function get() {
      return this.useFastIcons ? FontIcon : Icon;
    }
  }, {
    key: "classNames",
    get: function get() {
      var column = this.column,
          columnIndex = this.columnIndex,
          styles = this.styles,
          theme = this.theme,
          _this$cellStyleProps = this.cellStyleProps,
          cellStyleProps = _this$cellStyleProps === void 0 ? DEFAULT_CELL_STYLE_PROPS : _this$cellStyleProps;
      return getClassNames(styles, {
        theme: theme,
        headerClassName: column.headerClassName,
        iconClassName: column.iconClassName,
        isActionable: column.columnActionsMode !== ColumnActionsMode.disabled,
        isEmpty: !column.name,
        isIconVisible: column.isSorted || column.isGrouped || column.isFiltered,
        isPadded: column.isPadded,
        isIconOnly: column.isIconOnly,
        cellStyleProps: cellStyleProps,
        transitionDurationDrag: TRANSITION_DURATION_DRAG,
        transitionDurationDrop: TRANSITION_DURATION_DROP
      });
    }
  }, {
    key: "columnWidth",
    get: function get() {
      var column = this.column,
          cellStyleProps = this.cellStyleProps;
      return column.calculatedWidth + cellStyleProps.cellLeftPadding + cellStyleProps.cellRightPadding + (column.isPadded ? cellStyleProps.cellExtraRightPadding : 0) + 'px';
    }
  }]);

  return DetailsColumnBase;
}(BaseComponent);

__decorate([Prop({
  type: Object,
  required: true
}), __metadata("design:type", Object)], DetailsColumnBase.prototype, "column", void 0);

__decorate([Prop({
  type: Number,
  required: true
}), __metadata("design:type", Number)], DetailsColumnBase.prototype, "columnIndex", void 0);

__decorate([Prop({
  type: Number,
  default: null
}), __metadata("design:type", Number)], DetailsColumnBase.prototype, "parentId", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], DetailsColumnBase.prototype, "onColumnClick", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], DetailsColumnBase.prototype, "onColumnContextMenu", void 0);

__decorate([Prop({
  type: Object,
  default: null
}), __metadata("design:type", Object)], DetailsColumnBase.prototype, "dragDropHelper", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DetailsColumnBase.prototype, "isDraggable", void 0);

__decorate([Prop({
  type: Function,
  default: null
}), __metadata("design:type", Function)], DetailsColumnBase.prototype, "updateDragInfo", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], DetailsColumnBase.prototype, "isDropped", void 0);

__decorate([Prop({
  type: Object,
  default: function _default() {
    return DEFAULT_CELL_STYLE_PROPS;
  }
}), __metadata("design:type", Object)], DetailsColumnBase.prototype, "cellStyleProps", void 0);

__decorate([Prop({
  type: Boolean,
  default: true
}), __metadata("design:type", Boolean)], DetailsColumnBase.prototype, "useFastIcons", void 0);

DetailsColumnBase = __decorate([Component({
  components: {}
})], DetailsColumnBase);

export { DetailsColumnBase };
